Apphud

Greetings!

Apphud SDK is an open-source library for iOS and Android to manage auto-renewable subscriptions and other in-app purchases in your app.

Apphud has SDKs in iOS (Swift), Android (Kotlin), and cross-platform SDKs: React Native and Flutter.

What is Apphud?

Apphud is all-in-one infrastructure for your app growth. Apphud helps marketing and product management teams to make right decisions based on the data and tools.

Subscriptions Infrastructure

Integrate in-app purchases and subscriptions in your mobile app in 2 lines of code. No server code required. Apphud works with all apps on iOS, iPadOS, MacOS, tvOS, watchOS and Android. Cross-platform support out of the box.

Real-time Revenue Analytics

View key subscription metrics in our dashboard and charts, like MRR, Subscriber Retention (Cohorts), Churn rate, ARPU, Trial Conversions, Proceeds, Refunds, etc.

Integrations

Send subscription events to your favorite third party platforms with automatic currency conversion. Choose from 18 integrations, including: AppsFlyer, Adjust, Branch, Firebase, Amplitude, Mixpanel, OneSignal, Facebook, TikTok, and more. Custom Server-to-Server webhooks and APIs are also available.

A/B Experiments

Test different in-app purchases and paywalls. Run experiments to find the best combination of prices and purchase screen parameters that maximize ROI.

Web-to-App (iOS)

Web-to-App solution overcomes IDFA limitations in the post iOS 14.5 era. Using this solution you can run paid campaigns in Facebook or TikTok and get real-time attribution with nearly 100% accuracy.

Rules (iOS & Android)

Apphud may win back lapsed subscribers, reduce churn rate, get cancellation insights, send push notifications and many more using the mechanics below. This mechanics are called Rules. Choose between manual, scheduled and automated rule. Manual rules will be performed manually, scheduled rule will be performed on a certain time, automated rule will be triggered after certain event. Rules can present Figma paywall screens or legacy HTML screens.

Flutter integration

  1. Call Apphud.setRuleListener(...) to receive rule lifecycle events (appear, purchase, dismiss, survey). Screens are shown automatically.
  2. Optionally call Apphud.checkRules() to poll for unread rules immediately.
  3. Submit the push token after Apphud.start() via Apphud.submitPushNotificationsToken(...), and forward push payloads with Apphud.handlePushNotification(...).
    • iOS: APNs token / userInfo (see the example AppDelegate).
    • Android: FCM token / message.data (must include rule_id for Apphud rules; see the example ExampleFirebaseMessagingService).
  4. Use Apphud.pendingRule() / Apphud.showPendingRuleScreen() when you need pending-rule metadata or to present a delayed screen.

Why Apphud?

Complete mobile in-app purchases stack with no extra costs. Don’t waste time and money on building your own in-app purchases infrastructure. Use Apphud for free until your app revenue increases $10,000 per month.

Focused on data accuracy. Apphud provides the highest accuracy on app revenue tracking. Analyze all important app metrics with a confidence.

Trusted by thousands of mobile apps worldwide. From small apps earning a few thousands per month to a leading mobile-focused companies.

Support that really cares. With Apphud you can be sure you’re not alone with in-app subscription growth challenges. We proud of our zero-ignored tickets support – answering to every request in minutes! Customers success and priority support for Enterprise clients.

Retain users and grow revenue. Use our Rules to engage and re-engage subscribers with no code required. Run A/B pricing experiments to find a better price.

Installation

Create your account at Apphud for free. Please feel free to read our SDK Integration Guide.

Having a question?

If you have any questions or troubles with SDK integration feel free to contact us. We are online.

https://apphud.com/contacts

Like Apphud? Place a star at the top 😊

Libraries

apphud
listener/apphud_listener
listener/apphud_listener_handler
listener/apphud_rule_listener
listener/apphud_rule_listener_handler
models/apphud_models/android/android_purchase_wrapper
models/apphud_models/apphud_attribution_data
models/apphud_models/apphud_attribution_provider
models/apphud_models/apphud_composite_model
models/apphud_models/apphud_debug_level
models/apphud_models/apphud_error
models/apphud_models/apphud_group
models/apphud_models/apphud_non_renewing_purchase
models/apphud_models/apphud_paywall
models/apphud_models/apphud_paywalls
models/apphud_models/apphud_placement
models/apphud_models/apphud_placements
models/apphud_models/apphud_product
models/apphud_models/apphud_rule
models/apphud_models/apphud_subscription
models/apphud_models/apphud_user
models/apphud_models/apphud_user_property_key
models/apphud_models/composite/apphud_paywall_screen_show_result
models/apphud_models/composite/apphud_product_composite
models/apphud_models/composite/apphud_purchase_result
models/apphud_models/enums/ios_animation_style
models/extensions
models/product_details/one_time_purchase_offer_details_wrapper
models/product_details/pricing_phase_wrapper
models/product_details/product_details_wrapper
models/product_details/subscription_offer_details
models/sk_product/discount_payment_mode_wrapper
models/sk_product/discount_type_wrapper
models/sk_product/discount_wrapper
models/sk_product/sk_payment_transaction_wrapper
models/sk_product/sk_product_wrapper
models/sk_product/subscription_period_time_wrapper
models/sk_product/subscription_period_wrapper