ApphudNonRenewingPurchase class

Annotations
  • @JsonSerializable.new(anyMap: true)

Constructors

ApphudNonRenewingPurchase({required String productId, required double purchasedAt, required bool isActive, double? canceledAt, String? purchaseToken, String? platform, bool? isSandbox, bool? isLocal, bool? isConsumable})
ApphudNonRenewingPurchase.fromJson(Map map)
factory

Properties

canceledAt double?
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
final
isConsumable bool?
Returns true if purchase is consumable. On Android: Available directly from this property. On iOS: Use Apphud.isNonRenewingPurchaseConsumable(productId) async method instead.
final
isLocal bool?
Returns true if purchase was made using Local StoreKit Configuration File. Only available on iOS.
final
isSandbox bool?
Returns true if purchase is made in test environment. Only available on iOS.
final
platform String?
final
productId String
final
purchasedAt double
final
purchaseToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited