ApphudPaywallScreenShowResult class

Annotations
  • @JsonSerializable.new(anyMap: true)

Constructors

ApphudPaywallScreenShowResult({required bool success, required bool userClosed, ApphudError? error, ApphudSubscriptionWrapper? subscription, ApphudNonRenewingPurchase? nonRenewingPurchase, AndroidPurchaseWrapper? purchase, SKPaymentTransactionWrapper? transaction})
ApphudPaywallScreenShowResult.fromJson(Map map)
factory

Properties

error ApphudError?
Error information when the paywall operation failed. Only present when success is false and an error occurred.
final
hashCode int
The hash code for this object.
no setterinherited
nonRenewingPurchase ApphudNonRenewingPurchase?
Non-renewing purchase object when user completed a successful one-time purchase. Only present when success is true and the purchase was non-renewing.
final
purchase AndroidPurchaseWrapper?
Android purchase object when user completed a successful transaction. Only present when success is true on Android platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscription ApphudSubscriptionWrapper?
Subscription object when user completed a successful subscription purchase. Only present when success is true and the purchase was a subscription.
final
success bool
Indicates whether the paywall operation was successful.
final
transaction SKPaymentTransactionWrapper?
iOS transaction object when user completed a successful transaction. Only present when success is true on iOS platform.
final
userClosed bool
Indicates whether the user manually closed the paywall.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited