SKProductDiscountWrapper class

Annotations
  • @JsonSerializable.new(anyMap: true)

Constructors

SKProductDiscountWrapper({required double price, required int numberOfPeriods, required SKProductDiscountPaymentMode paymentMode, required SKPriceLocaleWrapper priceLocale, required SKProductSubscriptionPeriodWrapper subscriptionPeriod, String? identifier, SKProductDiscountType? type})
SKProductDiscountWrapper.fromJson(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
identifier String?
Identifier of the discount. Non-null only for promotional offers (type == SKProductDiscountType.subscription); null for introductory offers. This is the value to pass as discountID into Apphud.purchasePromo.
final
numberOfPeriods int
final
paymentMode SKProductDiscountPaymentMode
final
price double
final
priceLocale SKPriceLocaleWrapper
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod SKProductSubscriptionPeriodWrapper
final
type SKProductDiscountType?
Discount type: introductory vs promotional (subscription) offer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited