ApphudProduct class
- Annotations
-
- @JsonSerializable.new(anyMap: true)
Constructors
-
ApphudProduct({required String productId, required String store, String? name, ProductDetailsWrapper? productDetails, String? paywallIdentifier, SKProductWrapper? skProduct, String? placementIdentifier, Map<
String, dynamic> ? properties, String? variationIdentifier, String? experimentId}) - ApphudProduct.fromJson(Map map)
-
factory
Properties
- experimentId → String?
-
For internal usage (iOS).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- paywallIdentifier → String?
-
final
- placementIdentifier → String?
-
final
- productDetails → ProductDetailsWrapper?
-
final
- productId → String
-
final
-
properties
→ Map<
String, dynamic> ? -
Product configuration from Apphud Mission control (iOS).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skProduct → SKProductWrapper?
-
final
- store → String
-
final
- variationIdentifier → String?
-
For internal usage (iOS).
final
Methods
-
isCommitmentPlanPreferred(
) → bool - Returns true if the product has a commitment plan option configured in Mission control.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited