ApphudUser class
- Annotations
-
- @JsonSerializable.new(anyMap: true)
Constructors
-
ApphudUser({required String userId, required List<
ApphudSubscriptionWrapper> subscriptions, required List<ApphudNonRenewingPurchase> purchases, required List<ApphudPlacement> rawPlacements, required bool hasPurchases, int totalDevicesCount = 0, String internalId = '', String? experimentName, String? variationName, String? targetingName, String? remoteConfigString}) - ApphudUser.fromJson(Map json)
-
factory
Properties
- experimentName → String?
-
Name of the active A/B test experiment assigned to this user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPurchases → bool
-
Whether the user has any subscriptions or non-renewing purchases.
final
- internalId → String
-
Internal database id of the user. Should not be used in analytics.
final
-
purchases
→ List<
ApphudNonRenewingPurchase> -
final
-
rawPlacements
→ List<
ApphudPlacement> -
final
- remoteConfigString → String?
-
Raw JSON string for the app-level remote configuration assigned to this user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
ApphudSubscriptionWrapper> -
final
- targetingName → String?
-
Name of the targeting (audience) the user matches into.
final
- totalDevicesCount → int
-
Number of devices associated with the same userId.
final
- userId → String
-
final
- variationName → String?
-
Name of the active variation assigned to this user.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remoteConfig(
) → Map< String, dynamic> - Global app-level remote configuration payload for the active user variation.
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited